import logging
import os

from logtail import LogtailHandler

LOGGER_IS_NOT_INITIALIZED = True


def collect_logger():
    logger = logging.getLogger(__name__)
    global LOGGER_IS_NOT_INITIALIZED
    if LOGGER_IS_NOT_INITIALIZED:
        LOGGER_IS_NOT_INITIALIZED = False
        source_token = os.getenv("SOURCE_TOKEN")
        if source_token is None:
            logger.info("initialized local logger")
        else:
            handler = LogtailHandler(source_token=source_token)
            logger.setLevel(logging.INFO)
            log_format = logging.Formatter("%(message)s")
            handler.setFormatter(log_format)
            logger.handlers = []
            logger.addHandler(handler)
            logger.info("initialized betterstack logger")
    return logger



from gravybox.betterstack import collect_logger

logger = collect_logger()


class UpstreamAPIFailure(Exception):
    def __init__(self, query, upstream_api, upstream_status_code, upstream_content):
        super().__init__("upstream api failure")
        logger.warning(
            "upstream api failure",
            extra={"query": query,
                   "upstream_api": upstream_api,
                   "status_code": upstream_status_code,
                   "payload": upstream_content
                   }
        )


class UnexpectedCondition(Exception):
    def __init__(self, condition):
        super().__init__(f"encountered unexpected condition: {condition}")
        logger.warning(
            "encountered unexpected condition",
            extra={"condition": condition}
        )


class MalformedInput(Exception):
    def __init__(self, malformed_input):
        super().__init__(f"malformed input: {malformed_input}")
        logger.warning(
            "malformed input",
            extra={"malformed_input": malformed_input}
        )



from setuptools import setup

installation_requirements = [
    "logtail-python==0.2.10",
]

setup(
    name="gravybox",
    description="A big box of gravy for all of your flask-sloshing docker-aboded itty-bits. Enjoy at leisure.",
    version="0.8",
    url="https://github.com/clementinegroup/gravybox",
    author="(~)",
    package_dir={"": "packages"},
    packages=["gravybox"],
    install_requires=installation_requirements
)
